@@ -1,23 +1,16 @@
 # ABSTRACT: Data::Seek Data Structure Container
 package Data::Seek::Data;
 
-use Data::Object::Class;
-use Hash::Flatten ();
+use parent 'Data::Object::Hash';
 
-our $VERSION = '0.06'; # VERSION
-
-has 'object', is => 'ro';
+our $VERSION = '0.07'; # VERSION
 
 sub decode {
-    my $self   = shift;
-    my $object = $self->object // {};
-    return Hash::Flatten::unflatten $object;
+    return shift->unfold;
 }
 
 sub encode {
-    my $self   = shift;
-    my $object = $self->object // {};
-    return Hash::Flatten::flatten $object;
+    return shift->fold;
 }
 
 1;
@@ -34,7 +27,7 @@ Data::Seek::Data - Data::Seek Data Structure Container
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
