@@ -7,7 +7,7 @@ use Data::Seek::Search;
 
 use Data::Object::Class;
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 has 'datasets' => (
     is      => 'ro',
@@ -32,7 +32,7 @@ sub data {
         }
     }
 
-    $data = Data::Seek::Data->new(object => $data);
+    $data = Data::Seek::Data->new($data);
     return $data->decode;
 }
 
@@ -74,7 +74,7 @@ Data::Seek::Search::Result - Data::Seek Search Result Class
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
